/**
 * Describes an ExternalTask that the ProcessEngine has delegated to an
 * ExternalTask worker for processing.
 */
export declare class ExternalTask {
    private readonly _id;
    private readonly _workerId;
    private readonly _topic;
    private readonly _flowNodeInstanceId;
    private readonly _correlationId;
    private readonly _processInstanceId;
    private readonly _lockExpirationTime?;
    private readonly _payload;
    constructor(id: string, workerId: string, topic: string, flowNodeInstanceId: string, correlationId: string, processInstanceId: string, payload: any, lockExpirationTime?: Date);
    /**
     * The external tasks ID.
     */
    readonly id: string;
    /**
     * The ID of the worker that has most recently locked the ExternalTask
     * for processing.
     */
    readonly workerId: string;
    /**
     * The topic to which the ExternalTask belongs.
     */
    readonly topic: string;
    /**
     * The ID of the FlowNodeInstance that contains the definition
     * for the ExternalTask.
     */
    readonly flowNodeInstanceId: string;
    /**
     * The ID of the Correlation that contains the FlowNodeInstance with the
     * ExternalTask's definition.
     */
    readonly correlationId: string;
    /**
     * The ID of the ProcessInstance that contains the FlowNodeInstance with the
     * ExternalTask's definition.
     */
    readonly processInstanceId: string;
    /**
     * The lock expiration time. On expiration, the task is released to
     * be processed by other workers.
     * If not set, the ExternalTask is not locked.
     */
    readonly lockExpirationTime: Date;
    /**
     * The payload containing all relevant data the worker needs to execute the
     * ExternalTask.
     */
    readonly payload: any;
    /**
     * Determines whether the ExternalTask is currently locked or not.
     * A finished ExternalTask is always locked.
     */
    readonly isLocked: boolean;
}
